@@ -26,6 +26,7 @@
 /// @copybrief proton::null
 
 #include "./internal/config.hpp"
+#include "./internal/comparable.hpp"
 #include "./internal/export.hpp"
 
 #include <iosfwd>
@@ -35,13 +36,17 @@ namespace proton {
 /// The type of the AMQP null value
 ///
 /// @see @ref types_page
-class null {
+class null : private internal::comparable<null> {
   public:
     null() {}
 #if PN_CPP_HAS_NULLPTR
     /// Constructed from nullptr literal
     null(decltype(nullptr)) {}
 #endif
+    /// null instances are always equal
+  friend bool operator==(const null&, const null&) { return true; }
+    /// null instances are never unequal
+  friend bool operator<(const null&, const null&) { return false; }
 };
 
 /// Print a null value
